@@ -17,11 +17,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import os
 
 from datetime import (datetime, timedelta)
 from filecmp import dircmp
+from os.path import abspath
 
+from click.testing import CliRunner
 from expecter import expect
 from nose2.tools import params
 
@@ -62,7 +63,8 @@ def test_event_creation(task, start, delta, message):
     ('test_not_running', 3),
 )
 def test_read_datebase(database, events):
-    expect(len(Events.read('tests/data/' + database))) == events
+    evs = Events.read('tests/data/' + database, write_cache=False)
+    expect(len(evs)) == events
 
 
 @params(
@@ -75,35 +77,30 @@ def test_read_datebase(database, events):
 def test_check_events(n, task, start, delta):
     # FIXME: Clean-ish way to perform check, with the caveat that it parses the
     # database on each entry.  Need a better solution.
-    events = Events.read('tests/data/test')
+    events = Events.read('tests/data/test', write_cache=False)
     expect(events[n].task) == task
     expect(events[n].start) == start
     expect(events[n].delta) == delta
 
 
 def test_write_database():
-    events = Events.read('tests/data/test')
+    runner = CliRunner()
+    in_dir = abspath('tests/data/test')
+    events = Events.read(in_dir, write_cache=False)
     events._dirty = events.tasks()
-    try:
-        events.write('tests/data/test_write')
-    except:
-        pass
-    else:
-        comp = dircmp('tests/data/test', 'tests/data/test_write')
+    with runner.isolated_filesystem() as tempdir:
+        events.write(tempdir)
+        comp = dircmp(in_dir, tempdir)
         expect(comp.diff_files) == []
         expect(comp.left_only) == []
         expect(comp.right_only) == []
         expect(comp.funny_files) == []
-    finally:
-        for i in os.listdir('tests/data/test_write'):
-            os.unlink('tests/data/test_write/%s' % i)
-        os.rmdir('tests/data/test_write')
 
 
 def test_store_messages_with_events():
-    events = Events.read('tests/data/test')
+    events = Events.read('tests/data/test', write_cache=False)
     expect(events.last().message) == 'finished'
 
 
 def test_non_existing_database():
-    expect(Events()) == Events.read('I_NEVER_EXIST')
+    expect(Events()) == Events.read('I_NEVER_EXIST', write_cache=False)
